@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhrcfile.pl 2.18 01/10/06 20:02:06
+##	$Id: mhrcfile.pl,v 2.20 2002/05/02 01:34:30 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -36,6 +36,7 @@ sub read_resource_file {
     my($line, $tag, $label, $acro, $hr, $type, $routine, $plfile,
        $url, $arg, $tmp, @a);
     my($elem, $attr, $override, $handle, $pathhead, $chop);
+    local($_);
     $override = 0;
 
     $handle = &file_open($file);
@@ -80,6 +81,7 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq 'charsetconverters') {	# Charset filters
+	    $IsDefault{'CHARSETCONVERTERS'} = 0;
 	    if ($override) {
 		%readmail::MIMECharSetConverters = ();
 		%readmail::MIMECharSetConvertersSrc = ();
@@ -417,6 +419,7 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq 'mimedecoders') {		# Mime decoders
+	    $IsDefault{'MIMEDECODERS'} = 0;
 	    if ($override) {
 		%readmail::MIMEDecoders = ();
 		%readmail::MIMEDecodersSrc = ();
@@ -437,6 +440,7 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq 'mimefilters') {		# Mime filters
+	    $IsDefault{'MIMEFILTERS'} = 0;
 	    if ($override) {
 		%readmail::MIMEFilters = ();
 		%readmail::MIMEFiltersSrc = ();
@@ -457,6 +461,7 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq 'mimeargs') {		# Mime arguments
+	    $IsDefault{'MIMEARGS'} = 0;
 	    %readmail::MIMEFiltersArgs = ()  if $override;
 	    while (defined($line = <$handle>)) {
 		last  if     $line =~ /^\s*<\/mimeargs\s*>/i;
@@ -473,6 +478,7 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq 'mimeexcs') {		# Mime exclusions
+	    $IsDefault{'MIMEEXCS'} = 0;
 	    %readmail::MIMEExcs = ()  if $override;
 	    while (defined($line = <$handle>)) {
 		last  if $line =~ /^\s*<\/mimeexcs\s*>/i;
